==> kpublictransport-24.08.1-1.1-x86_64_v4.pkg.tar.zst: usr/lib/cmake/KPublicTransport/KPublicTransportTargets-noconfig.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file.
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KPublicTransport" for configuration ""
set_property(TARGET KPublicTransport APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KPublicTransport PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "KF6::I18n;KF6::I18nLocaleData"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKPublicTransport.so.24.08.1"
  IMPORTED_SONAME_NOCONFIG "libKPublicTransport.so.1"
  )

list(APPEND _cmake_import_check_targets KPublicTransport )
list(APPEND _cmake_import_check_files_for_KPublicTransport "${_IMPORT_PREFIX}/lib/libKPublicTransport.so.24.08.1" )

# Import target "KPublicTransportOnboard" for configuration ""
set_property(TARGET KPublicTransportOnboard APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KPublicTransportOnboard PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "KF6::NetworkManagerQt"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKPublicTransportOnboard.so.24.08.1"
  IMPORTED_SONAME_NOCONFIG "libKPublicTransportOnboard.so.1"
  )

list(APPEND _cmake_import_check_targets KPublicTransportOnboard )
list(APPEND _cmake_import_check_files_for_KPublicTransportOnboard "${_IMPORT_PREFIX}/lib/libKPublicTransportOnboard.so.24.08.1" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> kpublictransport-24.12.3-1.1-x86_64_v4.pkg.tar.zst: usr/lib/cmake/KPublicTransport/KPublicTransportTargets-noconfig.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file.
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KPublicTransport" for configuration ""
set_property(TARGET KPublicTransport APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KPublicTransport PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "KF6::I18n;KF6::I18nLocaleData;Qt6::Network"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKPublicTransport.so.24.12.3"
  IMPORTED_SONAME_NOCONFIG "libKPublicTransport.so.1"
  )

list(APPEND _cmake_import_check_targets KPublicTransport )
list(APPEND _cmake_import_check_files_for_KPublicTransport "${_IMPORT_PREFIX}/lib/libKPublicTransport.so.24.12.3" )

# Import target "KPublicTransportOnboard" for configuration ""
set_property(TARGET KPublicTransportOnboard APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KPublicTransportOnboard PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "Qt6::Network;Qt6::Qml;KF6::NetworkManagerQt"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKPublicTransportOnboard.so.24.12.3"
  IMPORTED_SONAME_NOCONFIG "libKPublicTransportOnboard.so.1"
  )

list(APPEND _cmake_import_check_targets KPublicTransportOnboard )
list(APPEND _cmake_import_check_files_for_KPublicTransportOnboard "${_IMPORT_PREFIX}/lib/libKPublicTransportOnboard.so.24.12.3" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
